@@ -121,6 +121,9 @@ class TestYCSpawn(NineSolsTestBase):
         self.assertReachableWith("FSP: Receive Peach Blossom Village Quest", [])
         self.assertReachableWith("Yinglong Canal: Near Root Node", [])
 
+        # regression test for duplicate Grapple bug
+        self.assertEqual(len([x for x in self.multiworld.get_items() if x.name == "Grapple"]), 0)
+
 
 class TestYCSpawnAllShuffle(NineSolsTestBase):
     options = {
@@ -137,6 +140,9 @@ class TestYCSpawnAllShuffle(NineSolsTestBase):
         self.assertReachableWith("FSP: Receive Peach Blossom Village Quest", [])
         self.assertNotReachableWith("Yinglong Canal: Near Root Node", [])  # because shuffle_ledge_grab
 
+        # regression test for duplicate Grapple bug
+        self.assertEqual(len([x for x in self.multiworld.get_items() if x.name == "Grapple"]), 1)
+
 
 class TestFGHSpawn(NineSolsTestBase):
     options = {
@@ -172,7 +178,7 @@ class TestOWSpawn(NineSolsTestBase):
     }
 
     def test_locations(self):
-        self.assertEqual(len(self.multiworld.get_reachable_locations()), 16)
+        self.assertEqual(len(self.multiworld.get_reachable_locations()), 15)
 
         self.assertReachableWith("OW: Above Sol Statue", [])
         self.assertReachableWith("Cortex Center: Near Left Exit", [])
@@ -308,7 +314,7 @@ class TestRPSpawn(NineSolsTestBase):
     }
 
     def test_locations(self):
-        self.assertEqual(len(self.multiworld.get_reachable_locations()), 7)
+        self.assertEqual(len(self.multiworld.get_reachable_locations()), 8)
 
 
 class TestRPSpawnAllShuffle(NineSolsTestBase):
@@ -321,7 +327,7 @@ class TestRPSpawnAllShuffle(NineSolsTestBase):
     run_default_tests = False
 
     def test_locations(self):
-        self.assertEqual(len(self.multiworld.get_reachable_locations()), 7)
+        self.assertEqual(len(self.multiworld.get_reachable_locations()), 8)
 
 
 class TestAFDSpawn(NineSolsTestBase):
